=========================
summarycombine_posteriors
=========================

The :code:`summarycombine_posteriors` executable is designed to combine two or
more sets of posterior samples. This executable is different from
`summarycombine <./summarycombine.html>`_ as :code:`summarycombine` combines
N files into a single metafile containing N analyses while
:code:`summarycombine_posteriors` combines N posterior samples and creates a
single file containing a single analysis.

To see help for this executable please run:

.. code-block:: console

    $ summarycombine_posteriors --help

.. program-output:: summarycombine_posteriors --help
